--WHEN ADDING:
	--GEAR TOKEN - Add the tier to the tierTypes list, add the new tokens in the "TOKENS" section and the Locale-enUS file
	--RAIDS      - Add the raid to the instances list
	--DUNGEONS   - Add the dungeon to the instances list
	--(Other)    - Add the other things to the list they belong to

local mod = UpgradeList:NewModule("ItemLocations")
local L = LibStub("AceLocale-3.0"):GetLocale("UpgradeList")

local UPGRADELIST_VERSION = GetAddOnMetadata('UpgradeList', 'Version')
local _, englishClass = UnitClass("player")

function UpgradeList:LoadDropdownItems()

	--Strings I Can't Extract From The Game--------------------------------------------------
		
	local raidTypes = {
		[1] = _G["PLAYER_DIFFICULTY2"],
		[2] = _G["PLAYER_DIFFICULTY1"],
		[3] = _G["PLAYER_DIFFICULTY3"],
	}
	
	local dungeonTypes = {
		[1] = _G["PLAYER_DIFFICULTY2"],
		[2] = _G["PLAYER_DIFFICULTY1"],
	}
	
	local currency = {
		[1] = L["Gear Token"],
		[2] = "396", --Valor Points
		[3] = "395", --Justice Points
		[4] = "390", --Conquest Points
		[5] = "392", --Honor Points
	}
	
	for cur,number in pairs(currency) do
		if cur ~= 1 then
			currency[cur] = GetCurrencyInfo(number)
		end
	end

	local tierTypes = {
		[1] = L["Tier 13"],
		[2] = L["Tier 12"],
		[3] = L["Tier 11"],
	}

	local reputationLevels = {
		[1] = _G["FACTION_STANDING_LABEL8"], --Exalted
		[2] = _G["FACTION_STANDING_LABEL7"], --Revered
		[3] = _G["FACTION_STANDING_LABEL6"], --Honored
		[4] = _G["FACTION_STANDING_LABEL5"], --Friendly
	}
		
	--Professions--------------------------------------------------------------------------------------
	local localizedProfessionNames = {
		[1] = "78670", --Archaeology
		[2] = "2259", --Alchemy
		[3] = "2018", --Blacksmithing
		[4] = "7411", --Enchanting
		[5] = "4036", --Engineering
		[6] = "45357", --Inscription
		[7] = "25229", --Jewelcrafting
		[8] = "2108", --Leatherworking
		[9] = "3908", --Tailoring
	}
	local professions = {}

	for prof,number in pairs(localizedProfessionNames) do
		professions[prof] = GetSpellInfo(number)
	end

	--Reputations--------------------------------------------------------------------------------------
	local numCataReps = GetCategoryNumAchievements(15072)
	local reputations = {}

	for i = 1, numCataReps, 1 do
		_, reputations[i] = GetAchievementInfo(15072, i)
	end

	--Instances----------------------------------------------------------------------------------------
	--Format: {Instance Type, InstanceID, Instance Name, Instance's Bosses (table), LFR mode available? (raids) OR normal mode available? (dungeons), Trash Drops?, Other ways to get gear (multi-boss drop, timed event, items, etc.)? }
		--Instance Type: 1-Raid, 2-Dungeon
	local instances = {
		{1, 187, "", {}, true, true, true}, --Dragon Soul
		{1, 78, "", {}, false, true, true}, --Firelands
		{1, 73, "", {}, false, true}, --Blackwing Descent
		{1, 72, "", {}, false, true}, --Bastion of Twilight
		{1, 74, "", {}, false, false}, --Throne of the Four Winds
		{1, 75, "", {}, false, false}, --Baradin Hold (list last in raids so it won't show up in Heroic modes)
		{2, 186, "", {}, false, true}, --Hour of Twilight
		{2, 185, "", {}, false, true}, --Well of Eternity
		{2, 184, "", {}, false, true}, --End Time
		{2, 77, "", {}, false, true, true}, --Zul'Aman
		{2, 76, "", {}, false, true}, --Zul'Gurub
		{2, 63, "", {}, false, true}, --Deadmines
		{2, 64, "", {}, false, true}, --Shadowfang Keep
		{2, 66, "", {}, true, true}, --Blackrock Caverns
		{2, 71, "", {}, true, true}, --Grim Batol
		{2, 70, "", {}, true, true}, --Halls of Origination
		{2, 69, "", {}, true, true}, --Lost City of the Tol'vir
		{2, 67, "", {}, true, true}, --The Stonecore
		{2, 65, "", {}, true, true}, --Throne of the Tides
		{2, 68, "", {}, true, true}, --Vortex Pinnacle
	}

	for i = 1, #instances do
		instances[i][3] = EJ_GetInstanceInfo(instances[i][2])
		local bossCounter = 1
		EJ_SelectInstance(instances[i][2])
		EJ_SetDifficulty(4) --picks up any heroic only bosses
		repeat
			instances[i][4][bossCounter] = EJ_GetEncounterInfoByIndex(bossCounter)
			bossCounter = bossCounter + 1
		until EJ_GetEncounterInfoByIndex(bossCounter) == nil
		EJ_SetDifficulty(1) --puts difficulty back to default setting
	end

	--Tokens-------------------------------------------------------------------------------------------
	--Format: [##] = {"token_number", "token_name", instance, boss, difficulty
	local tokens = {}
	local function GI(instanceID) --GI: GetInstance
		local name = EJ_GetInstanceInfo(instanceID)
		return name
	end
	local function GB(instanceID, bossIndex) --GB:GetBoss
		EJ_SelectInstance(instanceID)
		local boss = EJ_GetEncounterInfoByIndex(bossIndex)
		return boss
	end

	if (englishClass == "DEATHKNIGHT") or (englishClass == "DRUID") or (englishClass == "MAGE") or (englishClass == "ROGUE") then --Vanquisher
		tokens = {
			--Tier 11
			[1] = {"65002", "", GI(73), GB(73,6), L["Tier 11"], raidTypes[1]}, --Crown
			[2] = {"65089", "", GI(72), GB(72,4), L["Tier 11"], raidTypes[1]}, --Shoulders
			[3] = {"67425", "", GI(72), GB(72,1), L["Tier 11"], raidTypes[1]}, --Chest
			[4] = {"67431", "", GI(73), GB(73,2), L["Tier 11"], raidTypes[1]}, --Gauntlets
			[5] = {"67426", "", GI(73), GB(73,4), L["Tier 11"], raidTypes[1]}, --Leggings
			[6] = {"63682", "", GI(73), GB(73,6), L["Tier 11"], raidTypes[2]}, --Helm
			[7] = {"64314", "", GI(72), GB(72,4), L["Tier 11"], raidTypes[2]}, --Mantle
			--Tier 12
			[8] = {"71670", "", GI(78), GB(78,7), L["Tier 12"], raidTypes[1]}, --Crown 
			[9] = {"71673", "", GI(78), GB(78,6), L["Tier 12"], raidTypes[1]}, --Shoulders 
			[10] = {"71672", "", GI(78), GB(78,3), L["Tier 12"], raidTypes[1]}, --Chest 
			[11] = {"71669", "", GI(78), GB(78,5), L["Tier 12"], raidTypes[1]}, --Gauntlets 
			[12] = {"71671", "", GI(78), GB(78,4), L["Tier 12"], raidTypes[1]}, --Leggings 
			[13] = {"71668", "", GI(78), GB(78,7), L["Tier 12"], raidTypes[2]}, --Helm 
			[14] = {"71674", "", GI(78), GB(78,6), L["Tier 12"], raidTypes[2]}, --Mantle 
			--Tier 13
			[15] = {"78852", "", GI(187), GB(187,6), L["Tier 13"], raidTypes[1]}, --Crown
			[16] = {"78861", "", GI(187), GB(187,4), L["Tier 13"], raidTypes[1]}, --Shoulders
			[17] = {"78849", "", GI(187), GB(187,5), L["Tier 13"], raidTypes[1]}, --Chest
			[18] = {"78855", "", GI(187), GB(187,2), L["Tier 13"], raidTypes[1]}, --Gauntlets
			[19] = {"78858", "", GI(187), GB(187,3), L["Tier 13"], raidTypes[1]}, --Leggings
			[20] = {"78172", "", GI(187), GB(187,6), L["Tier 13"], raidTypes[2]}, --Crown
			[21] = {"78170", "", GI(187), GB(187,4), L["Tier 13"], raidTypes[2]}, --Shoulders
			[22] = {"78174", "", GI(187), GB(187,5), L["Tier 13"], raidTypes[2]}, --Chest
			[23] = {"78173", "", GI(187), GB(187,2), L["Tier 13"], raidTypes[2]}, --Gauntlets
			[24] = {"78171", "", GI(187), GB(187,3), L["Tier 13"], raidTypes[2]}, --Leggings
			[25] = {"78868", "", GI(187), GB(187,6), L["Tier 13"], raidTypes[3]}, --Crown
			[26] = {"78874", "", GI(187), GB(187,4), L["Tier 13"], raidTypes[3]}, --Shoulders
			[27] = {"78862", "", GI(187), GB(187,5), L["Tier 13"], raidTypes[3]}, --Chest
			[28] = {"78865", "", GI(187), GB(187,2), L["Tier 13"], raidTypes[3]}, --Gauntlets
			[29] = {"78871", "", GI(187), GB(187,3), L["Tier 13"], raidTypes[3]}, --Leggings
		}
	elseif (englishClass == "PALADIN") or (englishClass == "PRIEST") or (englishClass == "WARLOCK") then --Conqueror
		tokens = {
			--Tier 11
			[1] = {"65001", "", GI(73), GB(73,6), L["Tier 11"], raidTypes[1]}, --Crown 
			[2] = {"65088", "", GI(72), GB(72,4), L["Tier 11"], raidTypes[1]}, --Shoulders 
			[3] = {"67423", "", GI(72), GB(72,1), L["Tier 11"], raidTypes[1]}, --Chest 
			[4] = {"67429", "", GI(73), GB(73,2), L["Tier 11"], raidTypes[1]}, --Gauntlets 
			[5] = {"67428", "", GI(73), GB(73,4), L["Tier 11"], raidTypes[1]}, --Leggings 
			[6] = {"63683", "", GI(73), GB(73,6), L["Tier 11"], raidTypes[2]}, --Helm 
			[7] = {"64315", "", GI(72), GB(72,4), L["Tier 11"], raidTypes[2]}, --Mantle 
			--Tier 12
			[8] = {"71677", "", GI(78), GB(78,7), L["Tier 12"], raidTypes[1]}, --Crown 
			[9] = {"71680", "", GI(78), GB(78,6), L["Tier 12"], raidTypes[1]}, --Shoulders 
			[10] = {"71679", "", GI(78), GB(78,3), L["Tier 12"], raidTypes[1]}, --Chest 
			[11] = {"71676", "", GI(78), GB(78,5), L["Tier 12"], raidTypes[1]}, --Gauntlets 
			[12] = {"71678", "", GI(78), GB(78,4), L["Tier 12"], raidTypes[1]}, --Leggings 
			[13] = {"71675", "", GI(78), GB(78,7), L["Tier 12"], raidTypes[2]}, --Helm 
			[14] = {"71681", "", GI(78), GB(78,6), L["Tier 12"], raidTypes[2]}, --Mantle 
			--Tier 13
			[15] = {"78850", "", GI(187), GB(187,6), L["Tier 13"], raidTypes[1]}, --Crown
			[16] = {"78859", "", GI(187), GB(187,4), L["Tier 13"], raidTypes[1]}, --Shoulders
			[17] = {"78847", "", GI(187), GB(187,5), L["Tier 13"], raidTypes[1]}, --Chest
			[18] = {"78853", "", GI(187), GB(187,2), L["Tier 13"], raidTypes[1]}, --Gauntlets
			[19] = {"78856", "", GI(187), GB(187,3), L["Tier 13"], raidTypes[1]}, --Leggings
			[20] = {"78182", "", GI(187), GB(187,6), L["Tier 13"], raidTypes[2]}, --Crown
			[21] = {"78180", "", GI(187), GB(187,4), L["Tier 13"], raidTypes[2]}, --Shoulders
			[22] = {"78184", "", GI(187), GB(187,5), L["Tier 13"], raidTypes[2]}, --Chest
			[23] = {"78183", "", GI(187), GB(187,2), L["Tier 13"], raidTypes[2]}, --Gauntlets
			[24] = {"78181", "", GI(187), GB(187,3), L["Tier 13"], raidTypes[2]}, --Leggings
			[25] = {"78869", "", GI(187), GB(187,6), L["Tier 13"], raidTypes[3]}, --Crown
			[26] = {"78875", "", GI(187), GB(187,4), L["Tier 13"], raidTypes[3]}, --Shoulders
			[27] = {"78863", "", GI(187), GB(187,5), L["Tier 13"], raidTypes[3]}, --Chest
			[28] = {"78866", "", GI(187), GB(187,2), L["Tier 13"], raidTypes[3]}, --Gauntlets
			[29] = {"78872", "", GI(187), GB(187,3), L["Tier 13"], raidTypes[3]}, --Leggings
		}
	elseif (englishClass == "HUNTER") or (englishClass == "SHAMAN") or (englishClass == "WARRIOR") then --Protector
		tokens = {
			--Tier 11
			[1] = {"65000", "", GI(73), GB(73,6), L["Tier 11"], raidTypes[1]}, --Crown 
			[2] = {"65087", "", GI(72), GB(72,4), L["Tier 11"], raidTypes[1]}, --Shoulders 
			[3] = {"67424", "", GI(72), GB(72,1), L["Tier 11"], raidTypes[1]}, --Chest 
			[4] = {"67430", "", GI(73), GB(73,2), L["Tier 11"], raidTypes[1]}, --Gauntlets 
			[5] = {"67427", "", GI(73), GB(73,4), L["Tier 11"], raidTypes[1]}, --Leggings 
			[6] = {"63684", "", GI(73), GB(73,6), L["Tier 11"], raidTypes[2]}, --Helm 
			[7] = {"64316", "", GI(72), GB(72,4), L["Tier 11"], raidTypes[2]}, --Mantle 
			--Tier 12
			[8] = {"71684", "", GI(78), GB(78,7), L["Tier 12"], raidTypes[1]}, --Crown 
			[9] = {"71687", "", GI(78), GB(78,6), L["Tier 12"], raidTypes[1]}, --Shoulders 
			[10] = {"71686", "", GI(78), GB(78,3), L["Tier 12"], raidTypes[1]}, --Chest 
			[11] = {"71683", "", GI(78), GB(78,5), L["Tier 12"], raidTypes[1]}, --Gauntlets 
			[12] = {"71685", "", GI(78), GB(78,4), L["Tier 12"], raidTypes[1]}, --Leggings 
			[13] = {"71682", "", GI(78), GB(78,7), L["Tier 12"], raidTypes[2]}, --Helm 
			[14] = {"71688", "", GI(78), GB(78,6), L["Tier 12"], raidTypes[2]}, --Mantle 
			--Tier 13
			[15] = {"78851", "", GI(187), GB(187,6), L["Tier 13"], raidTypes[1]}, --Crown
			[16] = {"78860", "", GI(187), GB(187,4), L["Tier 13"], raidTypes[1]}, --Shoulders
			[17] = {"78848", "", GI(187), GB(187,5), L["Tier 13"], raidTypes[1]}, --Chest
			[18] = {"78854", "", GI(187), GB(187,2), L["Tier 13"], raidTypes[1]}, --Gauntlets
			[19] = {"78857", "", GI(187), GB(187,3), L["Tier 13"], raidTypes[1]}, --Leggings
			[20] = {"78177", "", GI(187), GB(187,6), L["Tier 13"], raidTypes[2]}, --Crown
			[21] = {"78175", "", GI(187), GB(187,4), L["Tier 13"], raidTypes[2]}, --Shoulders
			[22] = {"78179", "", GI(187), GB(187,5), L["Tier 13"], raidTypes[2]}, --Chest
			[23] = {"78178", "", GI(187), GB(187,2), L["Tier 13"], raidTypes[2]}, --Gauntlets
			[24] = {"78176", "", GI(187), GB(187,3), L["Tier 13"], raidTypes[2]}, --Leggings
			[25] = {"78870", "", GI(187), GB(187,6), L["Tier 13"], raidTypes[3]}, --Crown
			[26] = {"78876", "", GI(187), GB(187,4), L["Tier 13"], raidTypes[3]}, --Shoulders
			[27] = {"78864", "", GI(187), GB(187,5), L["Tier 13"], raidTypes[3]}, --Chest
			[28] = {"78867", "", GI(187), GB(187,2), L["Tier 13"], raidTypes[3]}, --Gauntlets
			[29] = {"78873", "", GI(187), GB(187,3), L["Tier 13"], raidTypes[3]}, --Leggings
		}
	end

	for i = 1, #tokens, 1 do
		tokens[i][2] = GetItemInfo(tokens[i][1])
	end

	function UpgradeList:LoadTierTokenNames()
		for i = 1, #tokens, 1 do
			tokens[i][2] = GetItemInfo(tokens[i][1])
		end
	end
	
	local generalItemLocations = {
		{_G["CHAT_MSG_RAID"], raidTypes, instances, instances},
		{_G["ENCOUNTER_JOURNAL_INSTANCE"], dungeonTypes, instances, instances},
		{_G["TRADE_SKILLS"], professions},
		{_G["QUESTS_LABEL"]},
		{_G["REPUTATION"], reputations, reputationLevels},
		{_G["PURCHASE"], currency, tierTypes, raidTypes, tokens},
		{_G["CHANNEL_CATEGORY_WORLD"]},
		{_G["OTHER"]},
	}
	
	self.db.Constants.GeneralItemLocations = generalItemLocations
	self.db.Constants.Instances = instances
	self.db.Constants.Professions = professions
	self.db.Constants.Reputations = reputations
	self.db.Constants.Currency = currency
	
end